summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/views/location_bar/location_bar_view.h
diff options
context:
space:
mode:
authorjered@chromium.org <jered@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-11 15:11:41 +0000
committerjered@chromium.org <jered@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-11 15:11:41 +0000
commitb1a843a461ca94274a5a1959a0c0aea71463545a (patch)
tree62660ce4db28185fa07fa2a11980342e92c79adc /chrome/browser/ui/views/location_bar/location_bar_view.h
parenta6da59e8dd0de10af11b469f392fbfa1cce66fd9 (diff)
downloadchromium_src-b1a843a461ca94274a5a1959a0c0aea71463545a.zip
chromium_src-b1a843a461ca94274a5a1959a0c0aea71463545a.tar.gz
chromium_src-b1a843a461ca94274a5a1959a0c0aea71463545a.tar.bz2
InstantExtended: Omnibox and location bar cleanup.
Remove the methods previously used to poke an InstantSuggestion object into the OmniboxEditModel through the LocationBar, since we're not doing that anymore. Keep but rename the view and model methods to draw gray text and deal with committing it, since it seems likely we'll revisit that UI; but rename methods which call gray text the "instant suggestion" to "gray text", since this is a generic autocompletion behavior not specific to Instant. BUG=251262 TEST=none R=erg@chromium.org, pkasting@chromium.org, shess@chromium.org, sky@chromium.org Review URL: https://codereview.chromium.org/18923004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@211117 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/views/location_bar/location_bar_view.h')
-rw-r--r--chrome/browser/ui/views/location_bar/location_bar_view.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.h b/chrome/browser/ui/views/location_bar/location_bar_view.h
index 61a112f..3ed517c 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.h
@@ -195,11 +195,11 @@ class LocationBarView : public LocationBar,
// comments on |ime_inline_autocomplete_view_|.
void SetImeInlineAutocompletion(const string16& text);
- // Invoked from OmniboxViewWin to show the instant suggestion.
- void SetInstantSuggestion(const string16& text);
+ // Invoked from OmniboxViewWin to show gray text autocompletion.
+ void SetGrayTextAutocompletion(const string16& text);
- // Returns the current instant suggestion text.
- string16 GetInstantSuggestion() const;
+ // Returns the current gray text autocompletion.
+ string16 GetGrayTextAutocompletion() const;
// Sets whether the location entry can accept focus.
void SetLocationEntryFocusable(bool focusable);
@@ -278,8 +278,6 @@ class LocationBarView : public LocationBar,
// LocationBar:
virtual void ShowFirstRunBubble() OVERRIDE;
- virtual void SetInstantSuggestion(
- const InstantSuggestion& suggestion) OVERRIDE;
virtual string16 GetInputString() const OVERRIDE;
virtual WindowOpenDisposition GetWindowOpenDisposition() const OVERRIDE;
virtual content::PageTransition GetPageTransition() const OVERRIDE;